@@ -8,25 +8,22 @@ extern crate clap;
 fn main() {
     let matches = clap_app!(pyxis =>
         (version: VERSION)
-        (about: "Does awesome things")
+        (about: "The pyxis package manager. Quickly builds and deploys images for netboot.")
         (@subcommand parcel =>
-            (@subcommand fetch =>
-                (@arg INPUT: +required "Sets the package to fetch from Arch repositories")
+            (@subcommand build =>
+                (@arg INPUT: +required "The package to build. provider|package.")
             )
         )
         (@subcommand image =>
             (@subcommand build =>
-                (@arg MANIFEST: +required "")
+                (@arg MANIFEST: +required "The package manifest from which to build the image")
             )
         )
     )
     .get_matches();
     if let Some(matches) = matches.subcommand_matches("parcel") {
-        if let Some(matches) = matches.subcommand_matches("fetch") {
-            pyxis_parcel_fetch(matches.value_of("INPUT").unwrap())
-        }
-        if let Some(matches) = matches.subcommand_matches("local") {
-            pyxis_parcel_local(matches.value_of("INPUT").unwrap())
+        if let Some(matches) = matches.subcommand_matches("build") {
+            pyxis_parcel_build_named(matches.value_of("INPUT").unwrap())
         }
     }
     if let Some(matches) = matches.subcommand_matches("image") {
